@@ -7,8 +7,7 @@ class MethodVersionNotFound(HTTPException):
     """*400* `Method Version Not Found` (Bad Request)
 
     Raise if the browser request method through an invalid method version ('Accept-Version').
-    (Raise if the browser sends something to the application the application
-    or server cannot handle).
+    (Raise if the browser sends something to the application or server cannot handle).
     """
 
     code = 400
